@@ -327,7 +327,23 @@ def pre_numba_vol_saturation_indice_rebalancing(price_data= None, inception_date
 
     print(f'backtesting with {rebalancing_method} method rebalancing since {inception_date} with early rebalancing {early_rebalancing}')
 
-    starting_indice = price_data.index.get_loc(inception_date)
+    #### getting the closest available date
+    starting_indice = None
+    try:
+        starting_indice = price_data.index.get_loc(inception_date)
+    except Exception:
+        pass
+
+    print("Oops!  That was no valid number.  Try again...")
+    gardefou = 0
+    while starting_indice is None and gardefou <1000:
+        gardefou=gardefou+1
+        inception_date=inception_date+timedelta(days=1)
+        try:
+            starting_indice = price_data.index.get_loc(inception_date)
+        except Exception:
+            pass
+
     previous_opened_date = price_data.index[starting_indice - 1]
     previous_histo_volatilities = turn_to_numba_dico(price_data.loc[previous_opened_date, vol_histo_underlyings].to_dict())
 
@@ -344,7 +360,6 @@ def pre_numba_vol_saturation_indice_rebalancing(price_data= None, inception_date
 
 
     assert inception_date in price_data.index
-    assert price_data.loc[inception_date,'is_rebalancing']
 
     assert price_data.shape[0] > 0
 
@@ -381,7 +396,7 @@ def flat_numba_vol_saturation_indice_rebalancing(returns, previous_histo_vol, re
     values = np.zeros(returns.shape[0])
     weights = np.zeros((returns.shape[0],returns.shape[1]))
     for i in range(returns.shape[0]):
-        if rebal[i]:
+        if rebal[i] or i == 0:
             current_weights = numba_flat_distribute_weights_risk(previous_histo_vol[i,:], capped_weights,risk_budget_allocations, target_vol)
             weights[i,:]= current_weights
             if i == 0:
