@@ -30,7 +30,7 @@ def rescalize(y, range1, range2):
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, selected_algo=None, aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon',number_per_year=252):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, selected_algo=None, aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon',number_per_year=252, apply_transaction_cost=True):
         super().__init__()
         self.starting_date = starting_date
         self.running_date = running_date
@@ -53,6 +53,7 @@ class AbstractRunner(ABC):
         self.starting_date = starting_date
         self.starting_iterations_to_pass = 20
         self.number_per_year = number_per_year
+        self.apply_transaction_cost = apply_transaction_cost
 
 
 
@@ -157,7 +158,7 @@ class  MixerRunner(AbstractRunner):
         print('confusion matrix')
         print(matrix)
 
-        transaction_cost = True
+        transaction_cost = self.apply_transaction_cost
         if self.frequence=='minutely':
             transaction_cost = False
 
